@@ -8,8 +8,8 @@ import platform
 import pytest
 from click.testing import CliRunner
 
+from sqlitebiter.__main__ import cmd
 from sqlitebiter._const import ExitCode
-from sqlitebiter.sqlitebiter import cmd
 
 from .common import print_traceback
 
