@@ -8,9 +8,9 @@ from pytablereader import SqliteFileLoader
 from simplesqlite import SimpleSQLite
 from tabledata import TableData
 
+from sqlitebiter.__main__ import cmd
 from sqlitebiter._const import ExitCode
 from sqlitebiter.converter._base import SourceInfo
-from sqlitebiter.sqlitebiter import cmd
 
 from .common import print_traceback
 
