@@ -9,9 +9,9 @@ import responses
 from click.testing import CliRunner
 from simplesqlite import SimpleSQLite
 
+from sqlitebiter.__main__ import cmd
 from sqlitebiter._const import ExitCode
 from sqlitebiter.converter._base import SourceInfo
-from sqlitebiter.sqlitebiter import cmd
 
 from .common import print_traceback
 from .dataset import complex_json
